from sort.countingSort import *

def main():
    A = [35, 24, 16, 21, 4, 72, 23, 9, 23, 14, 58, 12, 0]
    print("A[]:       ", A)
    print("Sorted A[]:", countingSort(A))

if __name__ == "__main__":
    main()
